var currentDestination;
var countryCode = "US";

function loadEntryWithPrice(data, destination) {
	var destDiv = $("div.artwork", destination);
	
	var img = $("<img>");
	
	img.load(function() {
		destDiv.css(
			"background-image",
			"url('" + this.src + "')");
	});
	
	if ($.trim(data.artworkURL).length) {
    	img[0].src = data.artworkURL;
	} else {
	   var iTunesID = data.url.match(/id([0-9]+)/)[1];
	   
    	$.getJSON(
    		"http://itunes.apple.com/lookup?country=" + escape(countryCode) + "&id=" + iTunesID,
    
    		function(iTunesData) {
        		var entry = iTunesData.results[0];
        		if (entry && entry.artworkUrl60) {
            		img[0].src = entry.artworkUrl60;
        		} else {
        		    img[0].src = "img/Missing-Picture-Placeholder.png";
        		}
    		}
    	);
	}
	
	$(".title", destination).text(data.title);
	$(".byline", destination).text(data.byline);
	$(".description", destination).html($("<div>").html(data.description).text().replace(/\n/g, "<br>"));
	$(".rating", destination).text(data.rating);
	$(".price", destination).text(data.formattedPrice);
	
	return destination.height() + 28;
}

function loadArtistContainer(data, destination) {
	destination.attr("id", "id-" + (new Date().getTime()));
	
	$.getJSON(
		"http://itunes.apple.com/lookup?country=" + escape(countryCode) + "&id=" + data.iTunesID + "&entity=allArtist,allTrack,album,movie,tvSeason,software,iPadSoftware,musicVideo,mix,audiobook,ebook,podcast,iTunesUPodcast,song,tvEpisode,podcastEpisode,iTunesUPodcastEpisode&limit=4",

		function(iTunesData) {
			for (var index = 0; index < iTunesData.resultCount; index++) {
				var entry = iTunesData.results[index];
				
				if (!entry.artworkUrl60) {
					continue;
				}
				
				var template = $("tr.album.template", destination).clone(true);
				template.removeClass("template");
				
				template.attr("href", entry.trackViewUrl ? entry.trackViewUrl : entry.collectionViewUrl ? entry.collectionViewUrl : "");
				$("img", template).attr("src", entry.artworkUrl60);
				$(".content h2", template).text(entry.trackName ? entry.trackName : entry.collectionName);
				
				if (entry.averageUserRating) {
					$(".content .rating", template).text(entry.averageUserRating);
				}
				
				$(".content .price", template).text(formattedPriceFromData(entry));
				
				template.appendTo($(".albums table", destination));
			}
			
			if (iTunesData.resultCount) {
				var albums = $(".albums", destination);
				
				console.log(albums);
				
				albums.css({
					display	: 'block',
					opacity : 0.0
				});
				
				albums.delay(500).animate({"opacity" : "1.0"});
				$(".spinner", destination).delay(500).animate({"opacity" : "0.0"});
			
				// console.log(destination.height());
				document.location.href = "http://resize.com/" + (destination.height() + 28);
			}
		}
	);
	
	$(".name", destination).text(data.title);

	return destination.height() + 28;
}

function formattedPriceFromData(data) {
	var price = (data.trackPrice ? data.trackPrice : data.collectionPrice);
	
	if (price == "") {
		return "";
	}
	
	var currencySymbol = "";
	
	switch (data.currency) {
		case "USD":
		case "CAD":
		case "MXN":
		case "AUD":
		case "NZD":
		
			currencySymbol = "$";
			break;
			
		case "GBP":
		
			currencySymbol = "£";
			break;
			
		case "EUR":
			currencySymbol = "€";
			break;
			
		case "CHF":
			currencySymbol = "CHF";
			break;
			
		case "DKK":
		case "NOK":
		case "SEK":
			currencySymbol = "kr";
			break;
			
		case "JPY":
			currencySymbol = "¥";
			break;
	}

	return currencySymbol + price;
}

function doSetData(data, newCountryCode) {
	if (newCountryCode) {
		countryCode = newCountryCode;
	}
	
	data = $.parseJSON(data);
	
	currentDestination.animate({"opacity" : 0.0}, function() {
	   $(this).html("");
	});
	
	if (currentDestination.attr("id") == "destinationOne") {
		currentDestination = $("#destinationTwo");
	} else {
		currentDestination = $("#destinationOne");
	}
	
	currentDestination.animate({"opacity" : 1.0});
	currentDestination.html("");

	var newDestination = currentDestination;
	
	if (data.formattedPrice) {
		var destination = $(".template.priceContainer").clone();

		destination.removeClass("template");
		destination.appendTo(newDestination);
		
		return loadEntryWithPrice(data, destination);
	} else {
		var destination = $(".template.artistContainer").clone();

		destination.removeClass("template");
		destination.appendTo(newDestination);

		return loadArtistContainer(data, destination);
	}
}

function switchToBackground(light) {
    if (light) {
        $(".destination").addClass("lightbackground");
        $(".spinner img").attr("src", "img/spinner-white.gif");
    } else {
        $(".destination").removeClass("lightbackground");
        $(".spinner img").attr("src", "img/spinner.gif");
    }
}

$(function() {
	currentDestination = $("#destinationTwo");
	
	// console.log(doSetData(artist));

//	switchToBackground(true);
//	doSetData(iTunesU);
//	doSetData(song);

});

